@@ -17,7 +17,8 @@ class _EventFramework:
 
     def _newworker(self, name=None, timedt=None):
         self._worker_id += 1
-        worker = Worker("worker" + str(self._worker_id - 1) + " of " + self.name if name is None else name, mindt= timedt if timedt else self.timedt)
+        worker = Worker("worker" + str(self._worker_id - 1) + " of " + self.name if name is None else name,
+                        mindt=timedt if timedt else self.timedt)
         if self._start_flag:
             worker.start()
         return worker
@@ -60,6 +61,11 @@ class EventFramework(_EventFramework):
         高效事件驱动框架
         Efficient event driven framework
 
+        # 重要说明:
+            小心死锁的情况(A调用(push)到B，但是B必须在A执行完后再能返回)，此时可以考虑使用parallel
+        #Important note:
+            Be careful of deadlock (A calls (pushes) to B, but B must return after A executes). In this case, you can consider using "parallel"
+
         :param name: str EventFrame's name.
                 _: None  # use default name
         :param capacity: int EventQueue's capacity. Mean the max size of eventqueue.
@@ -81,7 +87,7 @@ class EventFramework(_EventFramework):
         """
         super(EventFramework, self).__init__()
 
-        self.name = ("efr-" + name) if name else ("efr-" + NewRandomID(8))
+        self.name = (f"efr(name={name})") if name else (f"efr(name={NewRandomID(8)})")
         self.timedt = timedt
         self.log_path = log_path
         self.log_level = log_level
@@ -133,7 +139,7 @@ class EventFramework(_EventFramework):
         self._outputlogs()
         self._log(self.name + "quit.")
 
-    def login(self, station: EventStation, worker: Worker=None) -> bool:
+    def login(self, station: EventStation, worker: Worker = None) -> bool:
         """
         注册事件工作站。当update时，alloter会用调用station.filter(事件)->bool来判断station是否响应此事件。如果station响应了事件，那么alloter会把事件传入该station的队列.
         成功返回True，失败返回False
@@ -163,8 +169,6 @@ class EventFramework(_EventFramework):
             self.assign(None, station)
         return ret
 
-
-
     def push(self, event: Event, timeout: float = None) -> Event:
         """
         驱动事件。成功返回该event, 失败返回None
@@ -224,7 +228,7 @@ class EventFramework(_EventFramework):
         :return: bool
         """
         # print(worker, station)
-        if worker is None :
+        if worker is None:
             if station._worker:
                 ret = station._worker.removeTask(station._task)
                 station._worker = worker
@@ -238,8 +242,7 @@ class EventFramework(_EventFramework):
             station._task = Task(station.update, times=Task.CIRCLE)
             return worker.addTask(station._task)
 
-
-    def addWorker(self, name:str=None, timedt:int=None) -> Worker:
+    def addWorker(self, name: str = None, timedt: int = None) -> Worker:
         """
         添加一个工人到事件框架
         add a worker to eventframework.
@@ -275,6 +278,45 @@ class EventFramework(_EventFramework):
         """
         return self.ealloter.update()
 
+    def parallel(self, task: Task, *fn_args, delta=0.5, count=1, **fn_kwgs) -> Worker:
+        """
+        平行地做某事，用于执行一个task或是callable
+        Do something in parallel to execute a task or call
+
+        对于task:
+            执行一次还是无限循环取决于Task地的配置
+            后面的参数没用
+        对于callable:
+            只执行一次
+            后面的参数作为callable的参数
+        For task:
+            Whether to execute once or infinite loop depends on the configuration of the task
+            The following parameters are useless
+        For callable:
+            Execute only once
+            The following parameters are used as the parameters of callable
+
+        :param task: Task or callable
+        :param fn_args: args for task when task is a callable
+        :param delta: if it is executed in infinite loop mode, the corresponding working interval
+                _:0.5  unit:s
+        :param count: how many times to exec task when task is a callable
+                _:1
+        :param fn_kwgs: kwargs for task when task is a callable
+        :return: worker
+        """
+        worker = Worker(mindt=delta, always=False)
+        task = task if isinstance(task, Task) else Task(task, fn_args, fn_kwgs, times=count)
+        worker.addTask(task)
+        worker.start()
+        return worker
+
+    def __str__(self):
+        return self.name
+
+    def __repr__(self):
+        return str(self)
+
 
 if __name__ == '__main__':
     none = _PARAM_NONE()
